@@ -26,8 +26,8 @@ def bucket_name_part(length):
     return ''.join(random.choice(BUCKET_NAME_CHARS) for _ in range(length))
 
 
-def authorize(b2_auth_data):
+def authorize(b2_auth_data, api_config=DEFAULT_HTTP_API_CONFIG):
     info = InMemoryAccountInfo()
-    b2_api = B2Api(info)
+    b2_api = B2Api(info, api_config=api_config)
     b2_api.authorize_account("production", *b2_auth_data)
     return b2_api, info
